sequencetools.all_are_integer_equivalent_exprs
==============================================

.. autofunction:: abjad.tools.sequencetools.all_are_integer_equivalent_exprs.all_are_integer_equivalent_exprs
